You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spark.apache.org by an...@apache.org on 2015/06/20 02:40:06 UTC

spark git commit: [HOTFIX] [SPARK-8489] Correct JIRA number in previous commit

Repository: spark
Updated Branches:
  refs/heads/master 093c34838 -> bec40e52b


[HOTFIX] [SPARK-8489] Correct JIRA number in previous commit

It should be SPARK-8489, not SPARK-8498.


Project: http://git-wip-us.apache.org/repos/asf/spark/repo
Commit: http://git-wip-us.apache.org/repos/asf/spark/commit/bec40e52
Tree: http://git-wip-us.apache.org/repos/asf/spark/tree/bec40e52
Diff: http://git-wip-us.apache.org/repos/asf/spark/diff/bec40e52

Branch: refs/heads/master
Commit: bec40e52be1bbe8fd6f3a1daa6284429d6b5d841
Parents: 093c348
Author: Andrew Or <an...@databricks.com>
Authored: Fri Jun 19 17:39:26 2015 -0700
Committer: Andrew Or <an...@databricks.com>
Committed: Fri Jun 19 17:39:26 2015 -0700

----------------------------------------------------------------------
 .../regression-test-SPARK-8489/Main.scala       |  43 +++++++++++++++++++
 .../MyCoolClass.scala                           |  20 +++++++++
 .../regression-test-SPARK-8489/test.jar         | Bin 0 -> 6811 bytes
 .../regression-test-SPARK-8498/Main.scala       |  43 -------------------
 .../MyCoolClass.scala                           |  20 ---------
 .../regression-test-SPARK-8498/test.jar         | Bin 6811 -> 0 bytes
 .../spark/sql/hive/HiveSparkSubmitSuite.scala   |   8 ++--
 7 files changed, 67 insertions(+), 67 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala b/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala
new file mode 100644
index 0000000..e171517
--- /dev/null
+++ b/sql/hive/src/test/resources/regression-test-SPARK-8489/Main.scala
@@ -0,0 +1,43 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+import org.apache.spark.{SparkConf, SparkContext}
+import org.apache.spark.sql.hive.HiveContext
+
+/**
+ * Entry point in test application for SPARK-8489.
+ *
+ * This file is not meant to be compiled during tests. It is already included
+ * in a pre-built "test.jar" located in the same directory as this file.
+ * This is included here for reference only and should NOT be modified without
+ * rebuilding the test jar itself.
+ *
+ * This is used in org.apache.spark.sql.hive.HiveSparkSubmitSuite.
+ */
+object Main {
+  def main(args: Array[String]) {
+    println("Running regression test for SPARK-8489.")
+    val sc = new SparkContext("local", "testing")
+    val hc = new HiveContext(sc)
+    // This line should not throw scala.reflect.internal.MissingRequirementError.
+    // See SPARK-8470 for more detail.
+    val df = hc.createDataFrame(Seq(MyCoolClass("1", "2", "3")))
+    df.collect()
+    println("Regression test for SPARK-8489 success!")
+  }
+}
+

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala b/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala
new file mode 100644
index 0000000..b168174
--- /dev/null
+++ b/sql/hive/src/test/resources/regression-test-SPARK-8489/MyCoolClass.scala
@@ -0,0 +1,20 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+/** Dummy class used in regression test SPARK-8489. */
+case class MyCoolClass(past: String, present: String, future: String)
+

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar b/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar
new file mode 100644
index 0000000..4f59fba
Binary files /dev/null and b/sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar differ

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala b/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala
deleted file mode 100644
index 858dd6b..0000000
--- a/sql/hive/src/test/resources/regression-test-SPARK-8498/Main.scala
+++ /dev/null
@@ -1,43 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-import org.apache.spark.{SparkConf, SparkContext}
-import org.apache.spark.sql.hive.HiveContext
-
-/**
- * Entry point in test application for SPARK-8498.
- *
- * This file is not meant to be compiled during tests. It is already included
- * in a pre-built "test.jar" located in the same directory as this file.
- * This is included here for reference only and should NOT be modified without
- * rebuilding the test jar itself.
- *
- * This is used in org.apache.spark.sql.hive.HiveSparkSubmitSuite.
- */
-object Main {
-  def main(args: Array[String]) {
-    println("Running regression test for SPARK-8498.")
-    val sc = new SparkContext("local", "testing")
-    val hc = new HiveContext(sc)
-    // This line should not throw scala.reflect.internal.MissingRequirementError.
-    // See SPARK-8470 for more detail.
-    val df = hc.createDataFrame(Seq(MyCoolClass("1", "2", "3")))
-    df.collect()
-    println("Regression test for SPARK-8498 success!")
-  }
-}
-

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala b/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala
deleted file mode 100644
index a72c063..0000000
--- a/sql/hive/src/test/resources/regression-test-SPARK-8498/MyCoolClass.scala
+++ /dev/null
@@ -1,20 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-/** Dummy class used in regression test SPARK-8498. */
-case class MyCoolClass(past: String, present: String, future: String)
-

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar b/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar
deleted file mode 100644
index 4f59fba..0000000
Binary files a/sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar and /dev/null differ

http://git-wip-us.apache.org/repos/asf/spark/blob/bec40e52/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
----------------------------------------------------------------------
diff --git a/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala b/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
index 820af80..ab44303 100644
--- a/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
+++ b/sql/hive/src/test/scala/org/apache/spark/sql/hive/HiveSparkSubmitSuite.scala
@@ -67,13 +67,13 @@ class HiveSparkSubmitSuite
     runSparkSubmit(args)
   }
 
-  test("SPARK-8498: MissingRequirementError during reflection") {
-    // This test uses a pre-built jar to test SPARK-8498. In a nutshell, this test creates
+  test("SPARK-8489: MissingRequirementError during reflection") {
+    // This test uses a pre-built jar to test SPARK-8489. In a nutshell, this test creates
     // a HiveContext and uses it to create a data frame from an RDD using reflection.
     // Before the fix in SPARK-8470, this results in a MissingRequirementError because
     // the HiveContext code mistakenly overrides the class loader that contains user classes.
-    // For more detail, see sql/hive/src/test/resources/regression-test-SPARK-8498/*scala.
-    val testJar = "sql/hive/src/test/resources/regression-test-SPARK-8498/test.jar"
+    // For more detail, see sql/hive/src/test/resources/regression-test-SPARK-8489/*scala.
+    val testJar = "sql/hive/src/test/resources/regression-test-SPARK-8489/test.jar"
     val args = Seq("--class", "Main", testJar)
     runSparkSubmit(args)
   }


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@spark.apache.org
For additional commands, e-mail: commits-help@spark.apache.org